@@ -18,9 +18,9 @@ InvalidFilterWidget::InvalidFilterWidget(QWidget *parent)
 {
     auto vbox = new QVBoxLayout(this);
     vbox->setContentsMargins({});
-    auto lab =
-        new QLabel(i18n("The following filters are invalid (e.g. containing no actions "
-                        "or no search rules). Discard or edit invalid filters?"));
+    auto lab = new QLabel(i18nc("@label:textbox",
+                                "The following filters are invalid (e.g. containing no actions "
+                                "or no search rules). Discard or edit invalid filters?"));
     lab->setWordWrap(true);
     lab->setObjectName(QLatin1StringView("label"));
     vbox->addWidget(lab);
