@@ -26,15 +26,15 @@ public:
 
     SearchRule::Function function(const QByteArray &field, const QStackedWidget *functionStack) const override;
 
-    QString value(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const override;
+    [[nodiscard]] QString value(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const override;
 
-    QString prettyValue(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const override;
+    [[nodiscard]] QString prettyValue(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const override;
 
-    bool handlesField(const QByteArray &field) const override;
+    [[nodiscard]] bool handlesField(const QByteArray &field) const override;
 
     void reset(QStackedWidget *functionStack, QStackedWidget *valueStack) const override;
 
-    bool setRule(QStackedWidget *functionStack, QStackedWidget *valueStack, const SearchRule::Ptr rule, bool isBalooSearch) const override;
+    [[nodiscard]] bool setRule(QStackedWidget *functionStack, QStackedWidget *valueStack, const SearchRule::Ptr rule, bool isBalooSearch) const override;
 
     bool update(const QByteArray &field, QStackedWidget *functionStack, QStackedWidget *valueStack) const override;
 
